/**
 * 模拟微信接口
 */
var wx = {
    /**
     * 监听小游戏回到前台的事件（微信接口）
     * @param {Function} callback 小游戏回到前台的事件的回调函数
     */
    onShow: function (callback) {
        // callback();
    },

    /**
     * 取消监听小游戏回到前台的事件（微信接口）
     * @param {Function} callback 小游戏回到前台的事件的回调函数
     */
    offShow: function (callback) {},

    /**
     * 监听小游戏隐藏到后台事件（微信接口）
     * @param {Function} callback 小游戏隐藏到后台事件的回调函数
     */
    onHide: function (callback) {},

    /**
     * 取消监听小游戏隐藏到后台事件（微信接口）
     * @param {Function} callback 小游戏隐藏到后台事件的回调函数
     */
    offHide: function (callback) {},

    /**
     * 调用接口获取登录凭证（code）（微信接口）
     * @param {Object} object 
     */
    login: function (object) {
        try {
            var res = {
                code: ""
            };
            object.success && typeof object.success === "function" && object.success(res);
        } catch (err) {
            object.fail && typeof object.fail === "function" && object.fail(err);
        } finally {
            object.complete && typeof object.complete === "function" && object.complete();
        }
    },

    /**
     * 监听全局错误事件（微信接口）
     * @param {Function} callback 
     */
    onError: function (callback) {},

    /**
     * 取消监听全局错误事件（微信接口）
     * @param {Function} callback 
     */
    offError: function (callback) {},

    /**
     * 监听音频因为受到系统占用而被中断开始事件（微信接口）
     * @param {Function} callback 
     */
    onAudioInterruptionBegin: function (callback) {},

    /**
     * 取消监听音频因为受到系统占用而被中断开始事件（微信接口）
     * @param {Function} callback 
     */
    offAudioInterruptionBegin: function (callback) {},

    /**
     * 监听音频中断结束事件（微信接口）
     * @param {Function} callback 
     */
    onAudioInterruptionEnd: function (callback) {},

    /**
     * 取消监听音频中断结束事件（微信接口）
     * @param {Function} callback 
     */
    offAudioInterruptionEnd: function (callback) {},

    /**
     * 显示当前页面的转发按钮（微信接口）
     * @param {Object} object 
     */
    showShareMenu: function (object) {},

    /**
     * 隐藏转发按钮（微信接口）
     * @param {Object} object 
     */
    hideShareMenu: function (object) {},

    /**
     * 更新转发属性（微信接口）
     * @param {Object} object 
     */
    updateShareMenu: function (object) {},

    /**
     * 主动拉起转发，进入选择通讯录界面（微信接口）
     * @param {Object} object 
     */
    shareAppMessage: function (object) {},

    /**
     * 监听用户点击右上角菜单的「转发」按钮时触发的事件（微信接口）
     * @param {Function} callback 用户点击右上角菜单的「转发」按钮时触发的事件的回调函数
     */
    onShareAppMessage: function (callback) {},

    /**
     * 取消监听用户点击右上角菜单的「转发」按钮时触发的事件（微信接口）
     * @param {Function} callback 用户点击右上角菜单的「转发」按钮时触发的事件的回调函数
     */
    offShareAppMessage: function (callback) {},

    /**
     * 获取小游戏启动时的参数（微信接口）
     * @returns {Object} res
     */
    getLaunchOptionsSync: function () {
        var res = {
            screenWidth: window.innerWidth,
            screenHeight: window.innerHeight,
            statusBarHeight: 0,
            language: "zh_CN",
            system: "unknown",
            SDKVersion: "2.9.2",
            model: "unknown"
        };
        res.scene = 1001;
        res.query = {};
        res.shareTicket = "";
        res.referrerInfo = {};
        return res;
    },

    /**
     * 从本地缓存中异步获取指定 key 的内容（微信接口）
     * @param {*} object 
     */
    getStorage: function (object) {
        try {
            var value = localStorage.getItem(object.key);
            var res = {
                data: value
            }
            object.success && object.success(res);
        } catch (err) {
            object.fail && object.fail(err);
        } finally {
            object.complete();
        }
    },

    /**
     * 从本地缓存中同步获取指定 key 的内容（微信接口）
     * @param {string} key 本地缓存中指定的 key
     */
    getStorageSync: function (key) {
        return localStorage.getItem(key);
    },

    /**
     * 将数据存储在本地缓存中指定的 key 中 异步（微信接口）
     * @param {Object} object 
     */
    setStorage: function (object) {
        try {
            if (typeof object.data === "object") {
                object.data = JSON.stringify(object.data);
            }
            localStorage.setItem(object.key, object.data);
            object.success && object.success();
        } catch (err) {
            object.fail && object.fail();
        } finally {
            object.complete && object.complete();
        }
    },

    /**
     * 将数据存储在本地缓存中指定的 key 中 同步（微信接口）
     * @param {string} key 
     * @param {any} data 
     */
    setStorageSync: function (key, data) {
        if (typeof data === "object") {
            data = JSON.stringify(data);
        }
        localStorage.setItem(key, data);
    },

    aldSendEvent: function () {},

    /**
     * 检查登录态是否过期（微信接口）
     * @param {Object} object 
     */
    checkSession: function (object) {
        // object.success 未过期回调
        // object.fail 已经失效回调
        // object.complete 接口调用结束的回调函数
    },

    /**
     * 获取开放数据域（微信接口）
     */
    getOpenDataContext: function () {
        var ob = {};
        ob.postMessage = function () {}
        return ob;
    },

    /**
     * 获取系统信息 异步（微信接口）
     * @param {Object} object
     */
    getSystemInfo: function (object) {
        object.success && object.success({
            screenWidth: window.innerWidth,
            screenHeight: window.innerHeight,
            statusBarHeight: 0
        });
        object.complete && object.complete();
    },

    /**
     * 获取系统信息 同步（微信接口）
     */
    getSystemInfoSync: function () {
        var res = {};
        res.screenWidth = window.innerWidth;
        res.screenHeight = window.innerHeight;
        res.statusBarHeight = 0;
        return res;
    },

    /**
     * 创建内部 audio 上下文 InnerAudioContext 对象（微信接口）
     */
    createInnerAudioContext: function () {
        var audio = new Audio();
        audio.onEnded = function () {};
        audio.onCanplay = function () {};
        audio.stop = audio.pause;
        return audio;
    },

    /**
     * 使手机发生较长时间的振动（微信接口）
     * @param {Object} object
     */
    vibrateLong: function (object) {},

    /**
     * 使手机发生较短时间的振动（微信接口）
     * @param {Object} object 
     */
    vibrateShort: function (object) {},

    /**
     * 小游戏跳转（微信接口）
     * @param {object} res 跳转参数
     */
    navigateToMiniProgram: function (res) {
        console.log("wx navigateToMiniProgram");
        try {
            jta.gotoMarket && jta.gotoMarket();
            res.success && res.success();
        } catch (err) {
            res.fail && res.fail();
        } finally {
            res.complete && res.complete();
        }
    },

    /**
     * 网络请求（微信接口）
     */
    request: function (res) {
        var url = res.url;
        var data = res.data;
        var header = res.header;
        var method = res.method || "GET";
        var dataType = res.dataType;
        var responseType = res.responseType || "text";

        var xhr = new XMLHttpRequest();
        xhr.open(method, url, true);
        xhr.responseType = responseType;

        // 请求成功回调函数
        xhr.addEventListener('load', function (e) {
            var status = xhr.status;
            if ((status >= 200 && status < 300) || status === 304 || status == 0) {
                var result;
                if (xhr.responseType === 'text') {
                    result = xhr.responseText;
                } else if (xhr.responseType === 'document') {
                    result = xhr.responseXML;
                } else {
                    result = xhr.response;
                }
                // 注意:状态码200表示请求发送/接受成功,不表示业务处理成功
                res.success && res.success({
                    data: result,
                    statusCode: statusCode,
                    header: ""
                });
            } else {
                res.fail && res.fail(e);
            }
        });

        // 请求结束
        xhr.addEventListener('loadend', function (e) {
            res.complete && res.complete(e);
        });

        // 请求出错
        xhr.addEventListener('error', function (e) {
            res.fail && res.fail(e);
        });

        // 请求超时
        xhr.addEventListener('timeout', function (e) {
            res.fail && res.fail(e);
        });

        xhr.send();

        return xhr;
    }
}

var wx;
(function (wx) {
    var AsyncObject = /** @class */ (function () {
        function AsyncObject() {
        }
        return AsyncObject;
    }());
    wx.AsyncObject = AsyncObject;
    var CallbacksParser = /** @class */ (function () {
        function CallbacksParser() {
        }
        /**
         * @param {AsyncObject} res 待调用回调的变量
         * @param {any} arg 回调函数的参数
         */
        CallbacksParser.Success = function (res, arg) {
            var _onSuccess = CallbacksParser.ParseCallbacks(res).success;
            _onSuccess(arg);
        };
        /**
         * @param {AsyncObject} res 待调用回调的变量
         * @param {any} arg 回调函数的参数
         */
        CallbacksParser.Fail = function (res, arg) {
            var _onFail = CallbacksParser.ParseCallbacks(res).fail;
            _onFail(arg);
        };
        /**
         * 解析
         * @param {wx.AsyncObject}res
         */
        CallbacksParser.ParseCallbacks = function (res) {
            var succ = (res && typeof res.success == 'function') ? res.success : function () { };
            var fail = (res && typeof res.fail == 'function') ? res.fail : function () { };
            var comp = (res && typeof res.complete == 'function') ? res.complete : function () { };
            var succ_cb = function (arg) {
                try {
                    succ(arg);
                }
                finally {
                    comp(arg);
                }
            };
            var fail_cb = function (arg) {
                try {
                    fail(arg);
                }
                finally {
                    comp(arg);
                }
            };
            return {
                success: succ_cb,
                fail: fail_cb
            };
        };
        return CallbacksParser;
    }());
    wx.CallbacksParser = CallbacksParser;
})(wx || (wx = {}));
///<reference path = "lib.ts" />
/**
 * java提供的接口
 * 使用该接口可直接调用java层方法
 * ||后面为一套默认模板，防止jta对象未获取到导致程序报错
 */
var jta = jta || {
    /**
     * 展示提示信息
     * @param {string} msg 提示内容
     */
    showToast: function (msg) { },
    /**
     * 视频广告是否加载完成
     */
    isVideoCanPlay: function () {
        return false;
    },
    /**
     * 展示视频广告
     */
    showRewardedVideoAd: function () { },
    /**
     * 插屏广告是否加载完成
     */
    isFullCanPlay: function () {
        return false;
    },
    /**
     * 展示插屏广告
     */
    showInterstitialAd: function () { },
    /**
     * banner广告是否加载完成
     */
    isBannerCanPlay: function () {
        return false;
    },
    /**
     * 展示banner广告
     */
    showBannerAd: function () { },
    /**
     * 隐藏banner广告
     */
    closeBannerAd: function () { }
};
var wx;
(function (wx) {
    /**
     * 激励视频广告
     */
    var RewardedVideoAd = /** @class */ (function () {
        function RewardedVideoAd() {
        }
        /**
         * 获取激励视频广告单例
         */
        RewardedVideoAd.getInstance = function () {
            if (!this._instance) {
                this._instance = new RewardedVideoAd();
            }
            return this._instance;
        };
        /**
         * 加载激励视频广告
         * @returns {Promise}
         */
        RewardedVideoAd.prototype.load = function () {
            console.log("sdk -- RewardedVideoAd load");
            var t = this;
            return new Promise(function (resolve, reject) {
                setTimeout(function () {
                    callFunc(resolve);
                }, 500);
            });
        };
        /**
         * 显示激励视频广告
         * @returns {Promise}
         */
        RewardedVideoAd.prototype.show = function () {
            console.log("sdk -- RewardedVideoAd show");
            var t = this;
            return new Promise(function (resolve, reject) {
                if (jta.isVideoCanPlay()) {
                    jta.showRewardedVideoAd();
                    callFunc(resolve);
                }
                else {
                    jta.showToast("please try later!");
                    callFunc(reject);
                }
            });
        };
        /**
         * 销毁激励视频广告实例
         */
        RewardedVideoAd.prototype.destroy = function () { };
        /**
         * 监听激励视频广告加载事件
         * @param {Function} callback 激励视频广告加载事件的回调函数
         */
        RewardedVideoAd.prototype.onLoad = function (callback) {
            this.onLoadSuccess = callback;
        };
        /**
         * 取消监听激励视频广告加载事件
         * @param {Function} callback 激励视频广告加载事件的回调函数
         */
        RewardedVideoAd.prototype.offLoad = function (callback) {
            this.onLoadSuccess = null;
        };
        /**
         * 监听激励视频错误事件
         * @param {Function} callback 激励视频错误事件的回调函数：参数 {Object} res, 属性 {{string} errMsg, {number} errCode}
         */
        RewardedVideoAd.prototype.onError = function (callback) {
            this.onLoadFail = callback;
        };
        /**
         * 取消监听激励视频错误事件
         * @param {Function} callback 激励视频错误事件的回调函数
         */
        RewardedVideoAd.prototype.offError = function (callback) {
            this.onLoadFail = null;
        };
        /**
         * 监听用户点击 关闭广告 按钮的事件
         * @param {Function} callback 用户点击 关闭广告 按钮的事件的回调函数
         */
        RewardedVideoAd.prototype.onClose = function (callback) {
            this.onCloseCallback = callback;
        };
        /**
         * 取消监听用户点击 关闭广告 按钮的事件
         * @param {Function} callback 用户点击 关闭广告 按钮的事件的回调函数
         */
        RewardedVideoAd.prototype.offClose = function (callback) {
            this.onCloseCallback = null;
        };
        return RewardedVideoAd;
    }());
    /**
     * 插屏广告
     */
    var InterstitialAd = /** @class */ (function () {
        function InterstitialAd() {
        }
        /**
         * 获取插屏广告单例
         */
        InterstitialAd.getInstance = function () {
            if (!this._instance) {
                this._instance = new InterstitialAd();
            }
            return this._instance;
        };
        /**
         * 加载插屏广告
         * @returns {Promise}
         */
        InterstitialAd.prototype.load = function () {
            console.log("sdk -- InterstitialAd load");
            var t = this;
            return new Promise(function (resolve, reject) {
                setTimeout(function () {
                    callFunc(resolve);
                }, 500);
            });
        };
        /**
         * 显示插屏广告
         * @returns {Promise}
         */
        InterstitialAd.prototype.show = function () {
            console.log("sdk -- InterstitialAd show");
            var t = this;
            return new Promise(function (resolve, reject) {
                if (jta.isFullCanPlay()) {
                    jta.showInterstitialAd();
                    callFunc(resolve);
                }
                else {
                    console.log("InterstitialAd is loading, please try later!");
                    callFunc(reject);
                }
            });
        };
        /**
         * 销毁插屏广告实例
         */
        InterstitialAd.prototype.destroy = function () { };
        /**
         * 监听插屏广告加载事件
         * @param {Function} callback 插屏广告加载事件的回调函数
         */
        InterstitialAd.prototype.onLoad = function (callback) {
            this.onLoadSuccess = callback;
        };
        /**
         * 取消监听插屏广告加载事件
         * @param {Function} callback 插屏广告加载事件的回调函数
         */
        InterstitialAd.prototype.offLoad = function (callback) {
            this.onLoadSuccess = null;
        };
        /**
         * 监听插屏错误事件
         * @param {Function} callback 插屏错误事件的回调函数：参数 {Object} res, 属性 {{string} errMsg, {number} errCode}
         */
        InterstitialAd.prototype.onError = function (callback) {
            this.onLoadFail = callback;
        };
        /**
         * 取消监听插屏错误事件
         * @param {Function} callback 插屏错误事件的回调函数
         */
        InterstitialAd.prototype.offError = function (callback) {
            this.onLoadFail = null;
        };
        /**
         * 监听插屏广告关闭事件
         * @param {Function} callback 插屏广告关闭事件的回调函数
         */
        InterstitialAd.prototype.onClose = function (callback) {
            this.onCloseCallback = callback;
        };
        /**
         * 取消监听插屏广告关闭事件
         * @param {Function} callback 插屏广告关闭事件的回调函数
         */
        InterstitialAd.prototype.offClose = function (callback) {
            this.onCloseCallback = null;
        };
        return InterstitialAd;
    }());
    /**
     * Banner 广告
     */
    var BannerAd = /** @class */ (function () {
        function BannerAd() {
        }
        /**
         * 获取Banner广告单例
         */
        BannerAd.getInstance = function () {
            if (!this._instance) {
                this._instance = new BannerAd();
            }
            return this._instance;
        };
        /**
         * 显示 banner 广告
         * @returns {Promise}
         */
        BannerAd.prototype.show = function () {
            console.log("sdk -- BannerAd show");
            return new Promise(function (resolve, reject) {
                if (jta.isBannerCanPlay()) {
                    jta.showBannerAd();
                    callFunc(resolve);
                }
                else {
                    console.log("Banner is loading, please try later!");
                    callFunc(reject);
                }
            });
        };
        /**
         * 隐藏 banner 广告
         */
        BannerAd.prototype.hide = function () {
            console.log("sdk -- BannerAd hide");
            jta.closeBannerAd();
        };
        /**
         * 销毁 banner 广告
         */
        BannerAd.prototype.destroy = function () { };
        /**
         * 监听 banner 广告加载事件
         * @param {Function} callback banner 广告加载事件的回调函数
         */
        BannerAd.prototype.onLoad = function (callback) {
            this.onLoadSuccess = callback;
        };
        /**
         * 取消监听 banner 广告加载事件
         * @param {Function} callback banner 广告加载事件的回调函数
         */
        BannerAd.prototype.offLoad = function (callback) {
            this.onLoadSuccess = null;
        };
        /**
         * 监听 banner 广告错误事件
         * @param {Function} callback banner 广告错误事件的回调函数：参数 {Object} res, 属性 {{string} errMsg, {number} errCode}
         */
        BannerAd.prototype.onError = function (callback) {
            this.onLoadFail = callback;
        };
        /**
         * 取消监听 banner 广告错误事件
         * @param {Function} callback banner 广告错误事件的回调函数
         */
        BannerAd.prototype.offError = function (callback) {
            this.onLoadFail = null;
        };
        /**
         * 监听 banner 广告尺寸变化事件
         * @param {Function} callback banner 广告尺寸变化事件的回调函数: 参数 {Object} res, 属性 {{number} width, {number} height}
         */
        BannerAd.prototype.onResize = function (callback) { };
        /**
         * 取消监听 banner 广告尺寸变化事件
         * @param {Function} callback banner 广告尺寸变化事件的回调函数
         */
        BannerAd.prototype.offResize = function (callback) { };
        return BannerAd;
    }());
    /**
     * 调用方法，调用前对参数做判空处理
     * @param func
     */
    function callFunc(func) {
        if (func && typeof (func) === "function") {
            func();
        }
    }
    /**
     * 创建激励视频广告组件
     * @returns {RewardedVideoAd} 返回一个RewardedVideoAd实例
     */
    function createRewardedVideoAd(object) {
        console.log("sdk -- RewardedVideoAd create");
        var rewardedVideoAd = RewardedVideoAd.getInstance();
        setTimeout(function () {
            callFunc(rewardedVideoAd.onLoadSuccess);
        }, 500);
        return rewardedVideoAd;
    }
    wx.createRewardedVideoAd = createRewardedVideoAd;
    /**
     * 关闭视频广告回调
     * @param {boolean} isSuccess 视频广告是否播放结束
     */
    function OnVideoClose(isSuccess) {
        console.log("sdk -- RewardedVideoAd OnVideoClose:" + isSuccess);
        var rewardedVideoAd = RewardedVideoAd.getInstance();
        var res = {
            isEnded: true
        };
        if (!isSuccess) {
            res.isEnded = false;
        }
        callFunc(rewardedVideoAd.onCloseCallback);
        setTimeout(function () {
            callFunc(rewardedVideoAd.onLoadSuccess);
        }, 500);
    }
    wx.OnVideoClose = OnVideoClose;
    /**
     * 创建插屏广告
     * @returns {InterstitialAd} 返回一个InterstitialAd实例
     */
    function createInterstitialAd() {
        console.log("sdk -- InterstitialAd create");
        var interstitialAd = InterstitialAd.getInstance();
        setTimeout(function () {
            callFunc(interstitialAd.onLoadSuccess);
        }, 500);
        return interstitialAd;
    }
    wx.createInterstitialAd = createInterstitialAd;
    /**
     * 关闭插屏广告回调
     */
    function OnFullClose() {
        console.log("sdk -- InterstitialAd OnFullClose");
        var interstitialAd = InterstitialAd.getInstance();
        callFunc(interstitialAd.onCloseCallback);
        setTimeout(function () {
            callFunc(interstitialAd.onLoadSuccess);
        }, 500);
    }
    wx.OnFullClose = OnFullClose;
    /**
     * 创建banner广告
     * @returns {BannerAd} 返回一个BannerAd实例
     */
    function createBannerAd() {
        console.log("sdk -- BannerAd create");
        var bannerAd = BannerAd.getInstance();
        setTimeout(function () {
            callFunc(bannerAd.onLoadSuccess);
        }, 500);
        return bannerAd;
    }
    wx.createBannerAd = createBannerAd;
})(wx || (wx = {}));